@@ -40,6 +40,7 @@ GetOptions (\%options,
                luatex
                version
                verbose
+               coverpage-only-if-toc
                purge
                help/) or die "Bad option passed!\n";
 
@@ -221,6 +222,11 @@ Use lualatex instead of xelatex.
 
 Purge old files before compiling. Not supported for recursive compilation.
 
+=item --coverpage-only-if-toc
+
+Create a coverpage only if there is a table of contents, otherwise use
+an article class.
+
 =back
 
 =cut
